The Joker [YO-ker]
==================

.. image:: https://img.shields.io/badge/Made%20at-%23AstroHackWeek-8063d5.svg?style=flat
        :target: http://astrohackweek.org/
.. image:: https://circleci.com/gh/adrn/thejoker.svg?style=svg
        :target: https://circleci.com/gh/adrn/thejoker
.. image:: https://coveralls.io/repos/github/adrn/thejoker/badge.svg?branch=master
        :target: https://coveralls.io/github/adrn/thejoker?branch=master

A custom Monte Carlo sampler for the two-body problem.

Authors
-------

- **Adrian Price-Whelan** (Flatiron Institute)
- **David W. Hogg** (NYU, MPIA, & Flatiron Institute)
- **Dan Foreman-Mackey** (Flatiron Institute)

Installation
------------

To install the latest stable release, use `pip`::

    pip install thejoker

To install the development version::

    pip install git+https://github.com/adrn/thejoker

Attribution
-----------

.. image:: http://img.shields.io/badge/arXiv-1610.07602-orange.svg?style=flat
        :target: https://arxiv.org/abs/1610.07602
.. image:: https://img.shields.io/badge/ascl-1701.001-blue.svg?colorB=262255
        :target: http://ascl.net/1701.001
.. image:: https://zenodo.org/badge/67356932.svg
        :target: https://zenodo.org/badge/latestdoi/67356932

If you make use of this code, please cite the paper describing the method:
`Price-Whelan et al. 2017
<https://ui.adsabs.harvard.edu/#abs/2017ApJ...837...20P/abstract>`_

Documentation
-------------

.. image:: https://readthedocs.org/projects/thejoker/badge/?version=latest
        :target: http://thejoker.readthedocs.io/

See `the documentation <http://thejoker.readthedocs.io>`_ for information on how
to install and use The Joker.

License
-------

.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
        :target: https://github.com/adrn/thejoker/blob/master/LICENSE
